@@ -36,6 +36,7 @@ import operator
 import re
 from duration import Duration
 from musicalpitch import MusicalPitch
+from track import Track, PercussionTrack
 from engravers import *
 from requests import *
 from rat import Rat
@@ -493,28 +494,28 @@ class Score:
         kv.sort()
         if start is None and end is not None:
             return self._generate_midi_events(
-                     [i for i in kv if i < end], soundcard.Track)
+                     [i for i in kv if i < end], Track)
         elif start is not None and end is None:
             return self._generate_midi_events(
-                     [i for i in kv if i >= start], soundcard.Track)
+                     [i for i in kv if i >= start], Track)
         elif start is None and end is None:
-            return self._generate_midi_events(kv, soundcard.Track)
+            return self._generate_midi_events(kv, Track)
         else:
             assert start is not None and end is not None
             return self._generate_midi_events(
-               [i for i in kv if start <= i < end], soundcard.Track)
+               [i for i in kv if start <= i < end], Track)
     def get_first_beat_midi_events(self):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        return self._generate_midi_events([kv[0]], soundcard.Track)
+        return self._generate_midi_events([kv[0]], Track)
     def get_last_beat_midi_events(self):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        return self._generate_midi_events([kv[-1]], soundcard.Track)
+        return self._generate_midi_events([kv[-1]], Track)
     def get_midi_events_as_percussion(self):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        return self._generate_midi_events(kv, soundcard.PercussionTrack)
+        return self._generate_midi_events(kv, PercussionTrack)
     def _generate_midi_events(self, kv, tracktype):
         """
         kv is a list of rat.Rat that tell the timepos for all the tones
