@@ -121,6 +121,9 @@ class OSSSequencerSynth(oss_common.AbstractSynth):
             elif e[0] == midieventstream.BENDER:
                 print "FIXME: DevSequencerSynth.BENDER"
                 #solfege_d_midi.seq_bender(self.m_devnum, e[1], e[2])
+            elif e[0] == midieventstream.VOLUME:
+                print "oss_sequencer: seq_set_volume for /dev/sequencer not tested, so it is commented out."
+                #m.seq_set_volume(self.m_devnum, e[1], e[2])
             else:
                 raise Exception("oss_sequencer: play track error")
         solfege_c_midi.seqbuf_dump()
