@@ -66,6 +66,8 @@ class OSSSequencer2Synth(oss_common.AbstractSynth):
                 m.seq_set_patch(self.m_devnum, e[1], e[2])
             elif e[0] == midieventstream.BENDER:
                 m.seq_bender(self.m_devnum, e[1], e[2])
+            elif e[0] == midieventstream.VOLUME:
+                m.seq_set_volume(self.m_devnum, e[1], e[2])
             else:
                 raise Exception("oss_sequencer2: Corrupt midieventstream error")
         m.seqbuf_dump()
