@@ -182,6 +182,22 @@ _("You should configure sound from the 'Sound' page of the preferences window.")
             except (soundcard.SoundInitException, OSError, ImportError), e:
                 self.m_sound_init_exception = e
                 soundcard.initialise_using_fake_synth(True)
+        if cfg.get_string("programs/csound") == "AUTODETECT":
+            for p in osutils.find_csound_executables():
+                cfg.set_string("programs/csound", p)
+                break
+            else:
+                # If not csound binary was found, then we set the string empty.
+                # This means that autodetection will only happen the first time
+                # you run the program. But later will newly installed binaries
+                # be shown in the combo box of the preferences window.
+                cfg.set_string("programs/csound", "")
+        if cfg.get_string("programs/mma") == "AUTODETECT":
+            for p in osutils.find_mma_executables(cfg.get_list("app/win32_ignore_drives")):
+                cfg.set_string("programs/mma", p)
+                break
+            else:
+                cfg.set_string("programs/mma", "")
     def display_sound_init_error_message(self, e):
         if isinstance(e, soundcard.SoundInitException):
             self.m_ui.display_error_message(
