@@ -63,27 +63,23 @@ class Teacher(abstract.Teacher):
     def play_question(self):
         if self.q_status == self.QSTATUS_NO:
             return
-        low_instr, low_vel, high_instr, high_vel = self.get_instrument_config(2)
-        t1 = soundcard.Track()
-        t2 = soundcard.Track()
-        t1.set_patch(low_instr)
-        t2.set_patch(high_instr)
+        t1, t2 = utils.new_2_tracks()
         if self.get_string('first_interval_type') == 'harmonic':
-            t1.note(4, self.m_tonikas[0], low_vel)
-            t2.note(4, self.m_tonikas[0] + self.m_intervals[0], high_vel)
+            t1.note(4, self.m_tonikas[0])
+            t2.note(4, self.m_tonikas[0] + self.m_intervals[0])
         else:
-            t1.note(4, self.m_tonikas[0], low_vel)
+            t1.note(4, self.m_tonikas[0])
             t1.notelen_time(4)
             t2.notelen_time(4)
-            t2.note(4, self.m_tonikas[0] + self.m_intervals[0], high_vel)
+            t2.note(4, self.m_tonikas[0] + self.m_intervals[0])
         if self.get_string('last_interval_type') == 'harmonic':
-            t1.note(4, self.m_tonikas[1], low_vel)
-            t2.note(4, self.m_tonikas[1] + self.m_intervals[1], high_vel)
+            t1.note(4, self.m_tonikas[1])
+            t2.note(4, self.m_tonikas[1] + self.m_intervals[1])
         else:
-            t1.note(4, self.m_tonikas[1], low_vel)
+            t1.note(4, self.m_tonikas[1])
             t1.notelen_time(4)
             t2.notelen_time(4)
-            t2.note(4, self.m_tonikas[1] + self.m_intervals[1], high_vel)
+            t2.note(4, self.m_tonikas[1] + self.m_intervals[1])
         soundcard.synth.play_track(t1, t2)
     def guess_answer(self, c):
         """
@@ -110,7 +106,7 @@ class Gui(abstract.Gui):
         ##############
         self.practise_box.set_spacing(gu.PAD)
         hbox = gu.bHBox(self.practise_box)
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
         self.g_music_displayer.clear()
         hbox.pack_start(self.g_music_displayer)
 
