@@ -55,8 +55,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_notebook = gtk.Notebook()
         self.vbox.pack_start(self.g_notebook)
         
-        tooltips = gtk.Tooltips()
-        
         ########
         # midi #
         ########
@@ -81,7 +79,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             tempo_hbox.pack_start(widget, expand=False)
             label = gtk.Label(_("BPM"))
             label.set_alignment(0.0, 0.5)
-            tooltips.set_tip(label, _("Beats per minute"))
+            label.set_tooltip_text(_("Beats per minute"))
             tempo_hbox.pack_start(label, expand=True)        
         category_vbox.pack_start(tempo_hbox, False)
 
@@ -239,46 +237,35 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         box, category_vbox = gu.hig_category_vbox(_("Miscellaneous"))
         page_vbox.pack_start(box, False)
 
-        # CSound
-        liststore = gtk.ListStore(gobject.TYPE_STRING)
-        for p in osutils.find_progs(('csound', 'csound.exe')):
-            liststore.append((p,))
-        self.g_csound_exe = gtk.ComboBoxEntry(liststore)
-        self.g_csound_exe.child.set_text(self.get_string("programs/csound"))
-        self.g_csound_exe.connect('changed', lambda w: self.set_string('programs/csound', self.g_csound_exe.child.get_text()))
-        box = gu.hig_label_widget(_("CSound:"), self.g_csound_exe,
-            sizegroup, True, True)
-        category_vbox.pack_start(box)
-        # MMA
-        liststore = gtk.ListStore(gobject.TYPE_STRING)
-        for p in osutils.find_mma_executables(cfg.get_list("app/win32_ignore_drives")):
-            liststore.append((p,))
-        self.g_mma_exe = gtk.ComboBoxEntry(liststore)
-        self.g_mma_exe.child.set_text(self.get_string("programs/mma"))
-        self.g_mma_exe.connect('changed', lambda w: self.set_string('programs/mma', self.g_mma_exe.child.get_text()))
-        box = gu.hig_label_widget(_("Musical MIDI Accompaniment:"),
-            self.g_mma_exe, sizegroup, True, True)
-        category_vbox.pack_start(box)
-        # lilypond-book
-        liststore = gtk.ListStore(gobject.TYPE_STRING)
-        for p in osutils.find_progs(('lilypond-book',)):
-            liststore.append((p,))
-        self.g_lilypond_book_exe = gtk.ComboBoxEntry(liststore)
-        self.g_lilypond_book_exe.child.set_text(self.get_string("programs/lilypond-book"))
-        self.g_lilypond_book_exe.connect('changed', lambda w: self.set_string('programs/lilypond-book', self.g_lilypond_book_exe.child.get_text()))
-        box = gu.hig_label_widget(_("Lilypond-book:"),
-            self.g_lilypond_book_exe, sizegroup, True, True)
-        category_vbox.pack_start(box)
-        # latex
-        liststore = gtk.ListStore(gobject.TYPE_STRING)
-        for p in osutils.find_progs(('latex',)):
-            liststore.append((p,))
-        self.g_latex_exe = gtk.ComboBoxEntry(liststore)
-        self.g_latex_exe.child.set_text(self.get_string("programs/latex"))
-        self.g_latex_exe.connect('changed', lambda w: self.set_string('programs/latex', self.g_latex_exe.child.get_text()))
-        box = gu.hig_label_widget(_("Latex:"),
-            self.g_latex_exe, sizegroup, True, True)
-        category_vbox.pack_start(box)
+        # CSound_("Musical MIDI Accompaniment:")
+        for bin, label, bins in (
+            ("csound", _("CSound:"), osutils.find_csound_executables()),
+            ("mma", "MMA:", osutils.find_mma_executables(
+                cfg.get_list("app/win32_ignore_drives"))),
+            ("lilypond-book", _("Lilypond-book"),
+             osutils.find_progs(("lilypond-book", "lilypond-book.py"))),
+            ("latex", "Latex:", osutils.find_progs(("latex",))),
+            ):
+            liststore = gtk.ListStore(gobject.TYPE_STRING)
+            for p in bins:
+                liststore.append((p,))
+            cbox_entry = gtk.ComboBoxEntry(liststore)
+            cbox_entry.child.set_text(self.get_string("programs/%(bin)s" % locals()))
+            def csound_changed_cb(widget, bin):
+                self.set_string('programs/%s' % bin, widget.child.get_text())
+                widget.warning.props.visible = not bool(
+                    osutils.find_progs((cfg.get_string('programs/%s' % bin),)))
+            cbox_entry.warning = gtk.Image()
+            cbox_entry.warning.set_tooltip_text(_("Not found. Much of GNU Solfege will run fine without this program. You will get a message when the program is required, and the user manual will explain what you need it for."))
+            cbox_entry.warning.set_from_stock(gtk.STOCK_DIALOG_WARNING,
+                                              gtk.ICON_SIZE_SMALL_TOOLBAR)
+            box = gu.hig_label_widget(label,
+                                      [cbox_entry, cbox_entry.warning],
+                                      sizegroup, True, True)
+            category_vbox.pack_start(box)
+            cbox_entry.warning.props.no_show_all = True
+            csound_changed_cb(cbox_entry, bin)
+            cbox_entry.connect('changed', csound_changed_cb, bin)
         # Mail program
         liststore = gtk.ListStore(gobject.TYPE_STRING)
         for n in osutils.find_progs(('mutt', 'thunderbird', 'evolution')):
