@@ -31,7 +31,7 @@ class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
         abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.HeaderLessonfile
-        self.m_statistics = statistics.LessonStatistics(self)
+        self.m_statistics = statistics.IdToneStatistics(self)
         self.m_ask_tones =   {}
         self.m_question = None
         self.m_custom_mode = False
@@ -217,7 +217,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
                     raise
         self.set_percentage_label()
     def flash_and_play_first_tone(self):
-        self.g_flashbar.flash(_("First tone is %s") % self.m_t.m_question)
+        self.g_flashbar.flash(_("First tone is %s") % mpd.MusicalPitch.new_from_notename(self.m_t.m_question).get_user_notename())
         self.m_t.play_question()
     def on_answer_from_user(self, notename):
         if self.m_t.q_status == self.QSTATUS_NO:
@@ -255,7 +255,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
     def give_up(self, _o=None):
         if self.m_t.q_status == self.QSTATUS_WRONG:
             self.g_flashbar.push(_("The answer is: %s")
-                % self.m_t.m_question)
+                % mpd.MusicalPitch.new_from_notename(self.m_t.m_question).get_user_notename())
             self.m_t.give_up()
             self.g_new_tone.set_sensitive(True)
             self.g_new_tone.grab_focus()
