@@ -130,7 +130,7 @@ class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
         #
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(None)
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
         self.practise_box.pack_start(self.g_music_displayer, False)
         #
         self.g_tap = gu.bButton(self.practise_box, _("Tap here"), self.on_tap)
