@@ -1,5 +1,5 @@
 # Solfege - free ear training software
-# Copyright (C) 2007 Tom Cato Amundsen
+# Copyright (C) 2007, 2008 Tom Cato Amundsen
 # License is GPL, see file COPYING
 
 # Utility functions used by the test suite.
@@ -13,7 +13,7 @@ outdir = 'test-outdir'
 class I18nSetup(unittest.TestCase):
     def setUp(self):
         self.__saved_LANGUAGE = os.environ.get('LANGUAGE', None)
-        os.environ['LANGUAGE'] = 'no'
+        os.environ['LANGUAGE'] = 'nb'
         src.i18n.setup(".")
     def tearDown(self):
         if self.__saved_LANGUAGE:
